const fs = require('fs');
const webpackConfigHelpers = require('webpack-reconfig');
const paths = require('../../config/paths');

module.exports = function loadWebpackConfig(entryFiles, dllConfig) {
  let createWebpackConfig;
  if (process.env.NODE_ENV === 'production') {
    createWebpackConfig = require('../../config/webpack/config.prod');
  } else {
    // default to dev
    createWebpackConfig = require('../../config/webpack/config.dev');
  }

  const hasAppWebpackConfig = fs.existsSync(paths.appWebpackConfig);
  let appWebpackConfig;
  if (hasAppWebpackConfig) {
    appWebpackConfig = require(paths.appWebpackConfig);
    if (typeof appWebpackConfig === 'function') {
      appWebpackConfig = appWebpackConfig(webpackConfigHelpers);
    }
  }

  function makeConfig(entryConfig) {
    const config = createWebpackConfig(entryConfig, dllConfig);
    if (appWebpackConfig) {
      return webpackConfigHelpers.make(webpackConfigHelpers.extend(config, appWebpackConfig));
    }

    return webpackConfigHelpers.make(config);
  }

  return entryFiles.map(makeConfig);
};
